@@ -2,7 +2,7 @@
 
 ###############################################################################
 # polish.php
-# This is the Polish language page for GeekLog!
+# This is the Polish language file for Geeklog!
 # Special thanks to Robert Stadnik geeklog@geeklog.now.pl for his work on this project
 #
 # Copyright (C) 2000 Jason Whittenburg
@@ -80,7 +80,7 @@ $LANG01 = array(
     37 => 'Brak artykuw uytkownika',
     38 => 'Syndykacja Treci',
     39 => 'Odwie',
-    40 => 'Masz <tt>register_globals = Off</tt> w pliku <tt>php.ini</tt>. Niestety, Geeklog wymaga <tt>register_globals</tt> aby byy ustawione na <strong>on</strong>. Prosz zminie ustawienia na <strong>on</strong> i restartowa serwer www.',
+    40 => 'Masz <tt>register_globals = Off</tt> w pliku <tt>php.ini</tt>. Niestety, Geeklog wymaga <tt>register_globals</tt> aby byy ustawione na <strong>on</strong>. Prosz zmienie ustawienia na <strong>on</strong> i restartowa serwer www.',
     41 => 'Go',
     42 => 'Autor:',
     43 => 'Odpowiedz',
@@ -1579,90 +1579,90 @@ $LANG_CONFIG = array(
     'sections' => 'Configuration Sections',
     'restore' => 'Restore',
     'add_element' => 'Add Element',
-    'save_changes' => 'Save Changes',
-    'reset_form' => 'Reset Form',
+    'save_changes' => 'Zapisz zmiany',
+    'reset_form' => 'Resetuj zmiany',
     'changes_made' => 'Changes were successfully made to',
-    'title' => 'Configuration Manager',
-    'disable' => 'Click to disable this option'
+    'title' => 'Menader ustawie',
+    'disable' => 'Kliknij aby wyczy t opcj'
 );
 
 $LANG_configsections['Core'] = array(
     'label' => 'Geeklog',
-    'title' => 'Geeklog Configuration'
+    'title' => 'Konfiguracja Geeklog-a'
 );
 
 $LANG_confignames['Core'] = array(
-    'path_html' => 'HTML Path',
-    'site_url' => 'Site URL',
-    'site_admin_url' => 'Admin URL',
-    'site_mail' => 'Site E-Mail',
-    'noreply_mail' => 'No-Reply E-Mail',
-    'site_name' => 'Site Name',
+    'path_html' => 'cieka HTML',
+    'site_url' => 'Adres URL',
+    'site_admin_url' => 'Adres panelu administracyjnego',
+    'site_mail' => 'E-Mail strony',
+    'noreply_mail' => 'E-Mail w jedn stron',
+    'site_name' => 'Nazwa strony',
     'site_slogan' => 'Slogan',
-    'microsummary_short' => 'Microsummary',
+    'microsummary_short' => 'Mikro streszczenie',
     'path_log' => 'Log',
-    'path_language' => 'Language',
-    'backup_path' => 'Backup',
-    'path_data' => 'Data',
-    'path_images' => 'Images',
-    'path_pear' => 'Path Pear',
-    'have_pear' => 'Have Pear?',
-    'mail_settings' => 'Mail Settings',
-    'allow_mysqldump' => 'Allow MySQL Dump',
-    'mysqldump_path' => 'Path of Executable',
-    'mysqldump_options' => 'MySQL Dump Options',
-    'theme' => 'Theme',
-    'menu_elements' => 'Menu Elements',
-    'path_themes' => 'Themes Path',
-    'disable_new_user_registration' => 'Disable New Registrations',
-    'allow_user_themes' => 'Allow User Themes',
-    'allow_user_language' => 'Allow User Language',
-    'allow_user_photo' => 'Allow User Photo',
-    'allow_username_change' => 'Allow Username Changes',
-    'allow_account_delete' => 'Allow Account Deletion',
-    'hide_author_exclusion' => 'Allow Hide Author',
-    'show_fullname' => 'Show Fullname',
-    'show_servicename' => 'Show Service Name',
-    'custom_registration' => 'Enable Custom Registration',
-    'user_login_method' => 'User Login Method',
-    'spamx' => 'Spam-X Actions',
-    'sort_admin' => 'Sort Links',
-    'language' => 'Language',
-    'locale' => 'Locale',
-    'date' => 'Date Format',
-    'daytime' => 'Daytime Format',
-    'shortdate' => 'Short Date Format',
-    'dateonly' => 'Date Only Format',
-    'timeonly' => 'Time Only Format',
-    'week_start' => 'Week Start',
-    'hour_mode' => 'Hour Mode',
-    'thousand_separator' => 'Thousands Separator',
-    'decimal_separator' => 'Decimal Separator',
-    'decimal_count' => 'Decimal Count',
-    'language_files' => 'Language Files',
-    'languages' => 'Languages',
-    'timezone' => 'Timezone',
-    'site_disabled_msg' => 'Site Disabled Message or URL',
+    'path_language' => 'Jzyk',
+    'backup_path' => 'Kopia zapasowa',
+    'path_data' => 'Dane',
+    'path_images' => 'Zdjcia',
+    'path_pear' => 'cieka do Pear',
+    'have_pear' => 'Czy jest biblioteka Pear?',
+    'mail_settings' => 'Ustawienia poczty',
+    'allow_mysqldump' => 'Zezwalaj na zrzut MySQL',
+    'mysqldump_path' => 'cieka do plikw wykonawczych',
+    'mysqldump_options' => 'Opcje zrzutu MySQL',
+    'theme' => 'Layout',
+    'menu_elements' => 'Elementy Menu',
+    'path_themes' => 'cieka do katalogu z layoutami',
+    'disable_new_user_registration' => 'Wycz rejestracj nowych uytkownikw',
+    'allow_user_themes' => 'Uytkownik moe zmienia layout',
+    'allow_user_language' => 'Uytkownik moe zmienia jzyk',
+    'allow_user_photo' => 'Uytkownik moe doda swoje zdjcie',
+    'allow_username_change' => 'Uytkownik moe zmieni nazw konta',
+    'allow_account_delete' => 'Uytkownik moe usun swoje',
+    'hide_author_exclusion' => 'Zezwalaj na ukrycie autora',
+    'show_fullname' => 'Poka pen nazw uytkwonika',
+    'show_servicename' => 'Pokazuj nazw usugi',
+    'custom_registration' => 'Wcz wasn rejestracj',
+    'user_login_method' => 'Metoda logowania uytkownika',
+    'spamx' => 'Spam-X ustawienia',
+    'sort_admin' => 'Sortowanie odnonikw',
+    'language' => 'Jzyk',
+    'locale' => 'Opcje regionalne',
+    'date' => 'Format Daty',
+    'daytime' => 'Format daty dziennej',
+    'shortdate' => 'Format daty krtkiej',
+    'dateonly' => 'Tylko data - format',
+    'timeonly' => 'Tylko godzina - format',
+    'week_start' => 'Pocztek Tygodnia',
+    'hour_mode' => 'Tryb godzinowy',
+    'thousand_separator' => 'Separator tysiczny',
+    'decimal_separator' => 'Separator dziesitny',
+    'decimal_count' => 'Liczenie dziesitne',
+    'language_files' => 'Pliki jzykowe',
+    'languages' => 'Jzyki',
+    'timezone' => 'Strefa czasowa',
+    'site_disabled_msg' => 'Komunikat lub odnonik podczas wyczenia strony',
     'rootdebug' => 'Root Debugging',
-    'cookie_session' => 'Session Cookie Name',
-    'cookie_name' => 'Permanent Cookie Name',
-    'cookie_password' => 'Password Cookie Name',
-    'cookie_theme' => 'Theme Cookie Name',
-    'cookie_language' => 'Language Cookie Name',
-    'cookie_tzid' => 'Timezone Cookie Name',
-    'cookie_ip' => 'Cookies embed IP?',
-    'default_perm_cookie_timeout' => 'Permanent Timeout',
-    'session_cookie_timeout' => 'Session Timeout',
-    'cookie_path' => 'Cookie Path',
-    'cookiedomain' => 'Cookie Domain',
+    'cookie_session' => 'Nazwa ciasteczka sesji',
+    'cookie_name' => 'Nazwa ciasteczka staego',
+    'cookie_password' => 'Nazwa ciasteczka z hasem',
+    'cookie_theme' => 'Nazwa ciasteczka layoutu',
+    'cookie_language' => 'Nazwa ciasteczka jzykowego',
+    'cookie_tzid' => 'Nazwa ciasteczka strefy czasowej',
+    'cookie_ip' => 'Czy ciasteczko ma zawiera adres IP?',
+    'default_perm_cookie_timeout' => 'Stae wyganicie',
+    'session_cookie_timeout' => 'Wyganicie sesji',
+    'cookie_path' => 'cieka ciasteczek',
+    'cookiedomain' => 'Domena ciasteczek',
     'cookiesecure' => 'Cookie Secure',
-    'lastlogin' => 'Record Last Login?',
-    'pdf_enabled' => 'PDF Enabled?',
-    'num_search_results' => 'Number of Search Results',
-    'loginrequired' => 'Login Required?',
-    'submitloginrequired' => 'Submit Login Required?',
-    'commentsloginrequired' => 'Comment Login Required?',
-    'statsloginrequired' => 'Stats Login Required?',
+    'lastlogin' => 'Zarejestrowa ostatnie logowanie?',
+    'pdf_enabled' => 'PDF wczony?',
+    'num_search_results' => 'Liczba wynikw z wyszukiwarki',
+    'loginrequired' => 'Wymagane zalogowanie?',
+    'submitloginrequired' => 'Wymagane zalogowanie do przesania materiaw?',
+    'commentsloginrequired' => 'Wymagane zalogowanie do skomentowania?',
+    'statsloginrequired' => 'Wymagane zalogowanie do przegldania statystyk?',
     'searchloginrequired' => 'Search Login Required?',
     'profileloginrequired' => 'Profile Login Required?',
     'emailuserloginrequired' => 'E-Mail User Login Required?',
@@ -1708,33 +1708,33 @@ $LANG_confignames['Core'] = array(
     'pingback_excerpt' => 'Create Pingback Excerpt?',
     'link_documentation' => 'Link to Documentation?',
     'link_versionchecker' => 'Link to Version Checker?',
-    'maximagesperarticle' => 'Max Images per Article',
-    'limitnews' => 'Stories per Page',
-    'minnews' => 'Min. Stories per Page',
-    'contributedbyline' => 'Show "Contributed By"?"',
-    'hideviewscount' => 'Hide Views Count?',
-    'hideemailicon' => 'Hide E-Mail Icon?',
-    'hideprintericon' => 'Hide Print Icon?',
-    'allow_page_breaks' => 'Allow Page Breaks?',
-    'page_break_comments' => 'Comments on Multi-Page Articles',
-    'article_image_align' => 'Topic Icon Alignment',
-    'show_topic_icon' => 'Show Topic Icon?',
+    'maximagesperarticle' => 'Maks. liczba zdj w artykule',
+    'limitnews' => 'Liczba artykuw na stron',
+    'minnews' => 'Min. liczba artykuw na stron',
+    'contributedbyline' => 'Poka "Autor"?"',
+    'hideviewscount' => 'Ukryj liczb odson?',
+    'hideemailicon' => 'Ukryj ikon emaila?',
+    'hideprintericon' => 'Ukryj ikon drukowania?',
+    'allow_page_breaks' => 'Zezwalaj na amanie stron?',
+    'page_break_comments' => 'Komentarze dla artykuw wielostronicowych',
+    'article_image_align' => 'Wyrwnywanie ikon sekcji',
+    'show_topic_icon' => 'Poka ikon sekcji?',
     'draft_flag' => 'Draft Flag Default',
     'frontpage' => 'Frontpage Default',
     'hide_no_news_msg' => 'Hide "No News" Message?',
     'hide_main_page_navigation' => 'Hide Main Page Navigation?',
     'onlyrootfeatures' => 'Only Root can Feature?',
-    'aftersave_story' => 'After Saving Story',
-    'aftersave_user' => 'After Saving User',
-    'show_right_blocks' => 'Always Show Right Blocks?',
-    'showfirstasfeatured' => 'Show First Story as Featured?',
-    'backend' => 'Enable Feeds?',
-    'rdf_file' => 'Syndication Output Folder',
-    'rdf_limit' => 'Feed Limit',
-    'rdf_storytext' => 'Length of Stories in Feed',
-    'rdf_language' => 'Feed Language',
-    'syndication_max_headlines' => 'Max. Number of Headlines (portal blocks)',
-    'copyrightyear' => 'Copyright Year',
+    'aftersave_story' => 'Po zapisaniu artykuu',
+    'aftersave_user' => 'Po zapisaniu uytkownika',
+    'show_right_blocks' => 'Zawsze pokazuj prawe bloki?',
+    'showfirstasfeatured' => 'Poka pierwszy artyku jako Artyku Dnia?',
+    'backend' => 'Wcz kanay RSS?',
+    'rdf_file' => 'Katalog z plikami do syndykacji treci',
+    'rdf_limit' => 'Limit kanaw RSS',
+    'rdf_storytext' => 'Dugo artykuu w pliku RSS',
+    'rdf_language' => 'Jzyk kanau RSS',
+    'syndication_max_headlines' => 'Maks. liczba tytuw (bloki portalowe)',
+    'copyrightyear' => 'Prawa Autorskie Rok',
     'image_lib' => 'Image Library',
     'path_to_mogrify' => 'Path to Mogrify',
     'path_to_netpbm' => 'Path to Netpbm',
@@ -1770,7 +1770,7 @@ $LANG_confignames['Core'] = array(
     'censorreplace' => 'Censor Replace Text',
     'censorlist' => 'Censor List',
     'ip_lookup' => 'IP Lookup',
-    'url_rewrite' => 'Enable URL Rewrite',
+    'url_rewrite' => 'Wcz przyjazne adresy URL',
     'default_permissions_block' => 'Block Default Permissions',
     'default_permissions_story' => 'Story Default Permissions',
     'default_permissions_topic' => 'Topic Default Permissions',
@@ -1780,80 +1780,80 @@ $LANG_confignames['Core'] = array(
 );
 
 $LANG_configsubgroups['Core'] = array(
-    'sg_site' => 'Site',
-    'sg_stories' => 'Stories and Trackback',
-    'sg_theme' => 'Theme',
-    'sg_blocks' => 'Blocks',
-    'sg_users' => 'Users and Submissions',
-    'sg_images' => 'Images',
-    'sg_locale' => 'Languages and Locale',
-    'sg_misc' => 'Miscellaneous'
+    'sg_site' => 'Strona',
+    'sg_stories' => 'Artykuy i Powiadomienia Zwrotne',
+    'sg_theme' => 'Layout',
+    'sg_blocks' => 'Bloki',
+    'sg_users' => 'Uytkownicy i Przesane materiay',
+    'sg_images' => 'Zdjcia',
+    'sg_locale' => 'Jzyki i Ustawienia regionalne',
+    'sg_misc' => 'Rne'
 );
 
 $LANG_fs['Core'] = array(
-    'fs_site' => 'Site',
-    'fs_paths' => 'Paths',
-    'fs_theme' => 'Theme',
-    'fs_mail' => 'Mail',
+    'fs_site' => 'Strona',
+    'fs_paths' => 'cieki',
+    'fs_theme' => 'Layout',
+    'fs_mail' => 'Poczta',
     'fs_pear' => 'Pear',
     'fs_mysql' => 'MySQL',
-    'fs_users' => 'Users',
-    'fs_misc' => 'Miscellaneous',
+    'fs_users' => 'Uytkownicy',
+    'fs_misc' => 'Rne',
     'fs_spamx' => 'Spam-X',
     'fs_admin_block' => 'Admin Block',
-    'fs_locale' => 'Locale',
-    'fs_language' => 'Language',
+    'fs_locale' => 'Ustawienia regionalne',
+    'fs_language' => 'Jzyk',
     'fs_debug' => 'Debug',
-    'fs_cookies' => 'Cookies',
-    'fs_login' => 'Login Settings',
-    'fs_search' => 'Search',
-    'fs_user_submission' => 'User Submission',
-    'fs_submission' => 'Submission Settings',
-    'fs_topics_block' => 'Topics Block',
+    'fs_cookies' => 'Ciasteczka',
+    'fs_login' => 'Ustawienia logowania',
+    'fs_search' => 'Szukaj',
+    'fs_user_submission' => 'Materiay uytkownikw',
+    'fs_submission' => 'Ustawienia przesyania materiaw',
+    'fs_topics_block' => 'Blok sekcji',
     'fs_whosonline_block' => 'Who\'s Online Block',
     'fs_daily_digest' => 'Daily Digest',
-    'fs_whatsnew_block' => 'What\'s New Block',
+    'fs_whatsnew_block' => 'Nowoci',
     'fs_trackback' => 'Trackback',
     'fs_pingback' => 'Pingback',
-    'fs_story' => 'Story',
-    'fs_theme_advanced' => 'Advanced Settings',
-    'fs_syndication' => 'Syndication',
-    'fs_imagelib' => 'Image Library',
-    'fs_upload' => 'Upload',
-    'fs_articleimg' => 'Images in Articles',
-    'fs_topicicon' => 'Topic Icons',
-    'fs_userphoto' => 'Photos',
+    'fs_story' => 'Artyku',
+    'fs_theme_advanced' => 'Ustawienia zaawansowane',
+    'fs_syndication' => 'Syndykacja treci',
+    'fs_imagelib' => 'Katalog zdj',
+    'fs_upload' => 'aduj',
+    'fs_articleimg' => 'Zdjcia w artykuach',
+    'fs_topicicon' => 'Ikony sekcji',
+    'fs_userphoto' => 'Zdjcia',
     'fs_gravatar' => 'Gravatar',
-    'fs_comments' => 'Comments',
-    'fs_htmlfilter' => 'HTML Filtering',
-    'fs_censoring' => 'Censoring',
-    'fs_iplookup' => 'IP Lookup',
-    'fs_perm_story' => 'Story Default Permission',
-    'fs_perm_topic' => 'Topic Default Permission',
-    'fs_perm_block' => 'Block Default Permission',
-    'fs_webservices' => 'Webservices'
+    'fs_comments' => 'Komentarze',
+    'fs_htmlfilter' => 'Filtrowanie HTML',
+    'fs_censoring' => 'Cenzura',
+    'fs_iplookup' => 'Podgld IP',
+    'fs_perm_story' => 'Domylne ustawienia dla artykuw',
+    'fs_perm_topic' => 'Domylne ustawienia dla sekcji',
+    'fs_perm_block' => 'Domylne ustawienia dla blokw',
+    'fs_webservices' => 'Usugi WWW'
 );
 
 $LANG_configselects['Core'] = array(
-    0 => array('True' => 1, 'False' => 0),
-    1 => array('True' => true, 'False' => false),
-    2 => array('Reject' => 0, 'Only Keep Latest' => 1, 'Allow Multiple Posts' => 2),
-    3 => array('Trackback Enabled' => 0, 'Trackback Disabled' => -1),
-    4 => array('Don\'t Check Anything' => 0, 'Check against Site URL' => 1, 'Check full URL' => 2, 'Check against Site URL and full URL' => 3, 'Check IP against Site IP' => 4, 'Check IP and Site URL' => 5, 'Check IP and Full URL' => 6, 'Check IP, Full URL, and Site URL' => 7),
-    5 => array('Plain Old Text' => 'plaintext', 'HTML Formatted' => 'html'),
+    0 => array('Tak' => 1, 'Nie' => 0),
+    1 => array('Tak' => true, 'Nie' => false),
+    2 => array('Odrzu' => 0, 'Tylko Najnowsze' => 1, 'Zezwalaj na Wiele Postw' => 2),
+    3 => array('Trackback Wczony' => 0, 'Trackback Wyczony' => -1),
+    4 => array('Nie sprawdzaj Niczego' => 0, 'Sprawd wedle adresu strony' => 1, 'Sprawd cay URL' => 2, 'Sprawd wedle adresu strony i kompletnego URL' => 3, 'Check IP against Site IP' => 4, 'Sprawd IP i URL strony' => 5, 'Sprawd IP i peny URL' => 6, 'Sprawd IP, peny URL, i URL strony' => 7),
+    5 => array('Tekst' => 'plaintext', 'HTML' => 'html'),
     6 => array('12' => 12, '24' => 24),
-    7 => array('Last Page' => 'last', 'First Page' => 'first', 'Every Page' => 'all'),
-    8 => array('Right' => 'right', 'Left' => 'left'),
-    9 => array('Forward to page' => 'item', 'Display List' => 'list', 'Display Home' => 'home', 'Display Admin' => 'admin'),
-    10 => array('None' => '', 'Netpbm' => 'netpbm', 'ImageMagick' => 'imagemagick', 'gdLib' => 'gdlib'),
-    11 => array('Flat' => 'flat', 'Nested' => 'nested', 'Threaded' => 'threaded', 'No Comments' => 'nocomment'),
-    12 => array('No access' => 0, 'Read-Only' => 2, 'Read-Write' => 3),
-    13 => array('Skip' => 0, 'Allow, with speedlimit' => 1, 'Allow, no speedlimit' => 2),
-    14 => array('Sunday' => 'Sun', 'Monday' => 'Mon'),
-    15 => array('By Number' => 'sortnum', 'Alphabetically' => 'alpha'),
-    16 => array('No Login required' => 0, 'Advanced Search only' => 1, 'Simple + Advanced Search' => 2),
-    17 => array('Comments Enabled' => 0, 'Comments Disabled' => -1),
-    18 => array('Disabled' => 0, 'Enabled (Exact Match)' => 1, 'Enabled (Word Beginning)' => 2, 'Enabled (Word Fragment)' => 3)
+    7 => array('Ostatnia Strona' => 'last', 'Pierwsza Strona' => 'first', 'Wszystkie Strony' => 'all'),
+    8 => array('Prawa' => 'right', 'Lewa' => 'left'),
+    9 => array('Id do strony' => 'item', 'Poka list' => 'list', 'Poka stron gwn' => 'home', 'Poka panel sterowania' => 'admin'),
+    10 => array('Brak' => '', 'Netpbm' => 'netpbm', 'ImageMagick' => 'imagemagick', 'gdLib' => 'gdlib'),
+    11 => array('Lista' => 'flat', 'Chronologicznie' => 'nested', 'Wg wtku' => 'threaded', 'Bez komentarzy' => 'nocomment'),
+    12 => array('Brak dostpu' => 0, 'Tylko do Odczytu' => 2, 'Odczyt-Zapis' => 3),
+    13 => array('Pomi' => 0, 'Allow, with speedlimit' => 1, 'Allow, no speedlimit' => 2),
+    14 => array('Niedziela' => 'Sun', 'Poniedziaek' => 'Mon'),
+    15 => array('Liczbowo' => 'sortnum', 'Alfabetycznie' => 'alpha'),
+    16 => array('Login nie wymagany' => 0, 'Tylko wyszukiwanie zaawansowane' => 1, 'Wyszukiwanie proste + zaawansowane' => 2),
+    17 => array('Komentarze wczone' => 0, 'Komentarze wyczone' => -1),
+    18 => array('Wyczone' => 0, 'Wczone (Dokadne trafienie)' => 1, 'Wczone (Pocztek sowa)' => 2, 'Wczone (Fragment sowa)' => 3)
 );
 
-?>
\ No newline at end of file
+?>
